﻿using Microsoft.Practices.Prism.Events;
using Microsoft.Practices.Prism.Modularity;
using Microsoft.Practices.Prism.Regions;
using Microsoft.Practices.Unity;
using MsdnDemo.Infrastructure.Portable.Base;
using MsdnDemo.Infrastructure.Portable.Events;
using MsdnDemo.Infrastructure.Portable.Logger;
using MsdnDemo.Infrastructure.Portable.Types;
using MsdnDemo.Phone.Events;

namespace MsdnDemo.Base
{
    public class PresentationModuleBase : ModuleBase, IModule
    {
        [Dependency]
        public override ILogger Logger {get;set;}

        [Dependency]
        public IUnityContainer Container { get; set; }

        [Dependency]
        public IRegionManager RegionManager { get; set; }

        [Dependency]
        public IEventAggregator EventAggregator { get; set; }

        [Dependency]
        public IRegionViewRegistry RegionViewRegistry { get; set; }


        protected void RaiseViewEvent(string moduleName, string viewName, ProcessType processType)
        {
            EventAggregator.GetEvent<ViewEvent>().Publish(new ViewEventArgs
            {
                ModuleName = moduleName,
                ProcessType = ProcessType.ActivateView,
                ViewNameToActivate = viewName
            });
        }

        /// <summary>
        /// Notify the ApplicationController that the login was successful so that it can
        /// load (on demand) the password manager module (as configured in the Bootstrapper)
        /// Once modules are loaded they will not be loaded again so it is harmless on
        /// successive calls.
        /// </summary>
        /// <param name="moduleName">Name of the module.</param>
        /// <param name="viewName">Name of the view.</param>
        protected void RaiseModuleEvent(string moduleName, string viewName, ModuleEventType eventType)
        {
            EventAggregator.GetEvent<ModuleEvent>()
                .Publish(new ModuleEventArgs
                {
                    ModuleName = moduleName,
                    EventType = eventType,
                    PayLoad = viewName // The view to load on click
                });
        }

    }
}
