﻿using System.Collections.Generic;
using MsdnDemo.Infrastructure.Portable.Constants;
using MsdnDemo.Infrastructure.Portable.Entities;
using MsdnDemo.Infrastructure.Portable.Events;
using MsdnDemo.LayerBusinessLogic.Base;
using MsdnDemo.LayerBusinessLogic.Interfaces;

namespace MsdnDemo.LayerBusinessLogic
{
    public class RoleBll : BllBase<RoleEntity>, IRolesBll
    {
        private bool _isProcessing;


        /// <summary>
        /// When a List() is requested from the Bll it will end up
        /// here so that we can test to see if there are any roles
        /// configured.  If not we'll add the three default roles
        /// </summary>
        /// <param name="e"></param>
        protected override void ListDataArrivedHandler(DalEventArgs e)
        {
            base.ListDataArrivedHandler(e); // Logs process

            // We don't want to end up here recursively
            if (_isProcessing)
                return;

            try
            {
                _isProcessing = true; // Set processing flag

                var list = new List<RoleEntity>(
                    e.GetResults<IEnumerable<RoleEntity>>());

                // if there are no roles then create default roles
                if (list.Count == 0)
                {
                    var status = CreateDefaultRoles(e);

                    // If create was successful execute list
                    // again so that it can populate e.Results
                    if (status == StatusCode.Success)
                        List(e); // Read list
                }
            }
            finally
            {
                _isProcessing = false; // reset processing flag
            }
        }

        private int CreateDefaultRoles(DalEventArgs e)
        {
            var list = new List<RoleEntity>
                            {
                                new RoleEntity {
                                        Id = 1,
                                        Role = "Admin",
                                        Description = "Adminstrator role"
                                    },
                                new RoleEntity {
                                        Id = 2,
                                        Role = "User",
                                        Description = "Users role"
                                    },
                                new RoleEntity {
                                        Id = 3,
                                        Role = "Guest",
                                        Description = "Guest role"
                                    }
                            };
            
            // Iterate through defaults and create records
            foreach(var record in list)
            {
                var args = new DalEventArgs
                               {
                                   PrimaryKey = record.Id,
                                   Data = record
                               };
                
                // If process fails then return status
                var status = Create(args);
                if (status != StatusCode.Success)
                    return status;
            }
            return StatusCode.Success;
        }
    }
}
