﻿using Microsoft.Practices.Unity;
using MsdnDemo.Base;
using MsdnDemo.Infrastructure.Portable.Constants;
using MsdnDemo.Infrastructure.Portable.Entities;
using MsdnDemo.Infrastructure.Portable.Interfaces;
using MsdnDemo.LayerBusinessLogic;
using MsdnDemo.LayerBusinessLogic.Interfaces;
using MsdnDemo.LayerDataAccess;
using MsdnDemo.MvpVmPresenters;

namespace MsdnDemo.Modules
{
    public class SecurityModule : PresentationModuleBase
    {
        protected override void RegisterTypes()
        {
            base.RegisterTypes();

            Container // We'll let Sqlite handler our Bll/Dal
                // Roles
                .RegisterType<IRolesBll, RoleBll>()
                .RegisterType<IDal<RoleEntity>, RolesDal>()
                // User
                .RegisterType<IUserBll, UserBll>(new ContainerControlledLifetimeManager())
                .RegisterType<IDal<UserEntity>, UserDal>()
                // User Role
                .RegisterType<IUserRoleBll, UserRoleBll>()
                .RegisterType<IDal<UserRoleEntity>, UserRoleDal>()

                // Register the security view model as a singleton so that
                // we can get it's information (isauthenticated, username, etc)
                // from other modules/processes
                .RegisterType<ISecurityViewModel, SecurityEntity>(
                new ContainerControlledLifetimeManager());
        }

        protected override void RegisterViews()
        {
            base.RegisterViews(); // Log that we are here

            // Initialize system roles in userBll singleton
            Container.Resolve<IUserBll>().Initialize();

            // Instantiate the presenter, which in turn will instantiate
            // (resolve) the View, ViewModel, and dependencies
            var presenter = Container.Resolve<SecurityPresenter>();

            // Place the SecurityView in the MainRegion 
            RegionViewRegistry
                .RegisterViewWithRegion(MvpVm.MainRegion, () => presenter.View);
        }

    }
}
