﻿using System.Windows.Controls;
using Microsoft.Practices.Unity;
using MsdnDemo.Base;
using MsdnDemo.Infrastructure.Portable.Constants;
using MsdnDemo.Infrastructure.Portable.Events;
using MsdnDemo.Infrastructure.Portable.Interfaces;
using MsdnDemo.Infrastructure.Portable.Types;
using MsdnDemo.MvpVmViewModels;
using MsdnDemo.MvpVmViews;

namespace MsdnDemo.MvpVmPresenters
{
    public class GuestPresenter : PresentationPresenterBase<GuestView,MainViewModel>
    {
        [Dependency]
        public ISecurityViewModel SecurityViewModel { get; set; }
        
        protected override void Initialize()
        {
            base.Initialize(); // Logs initialize

            // Add the view model to the view model holder
            View.ViewModelHolder.Items.Add(ViewModel);
        }
        
        public override void ViewActivated(ViewEventArgs e)
        {
            base.ViewActivated(e);
            
            ViewModel.Message = null; // reset

            // Assign role flags as applicable
            ViewModel.IsGuest = SecurityViewModel.IsInRole("Guest");
        }

        protected override void ExecuteButtonCommandHandler(object sender, DelegateCommandEventArgs e)
        {
            base.ExecuteButtonCommandHandler(sender, e); // Log we are here

            switch (((Button)e.Sender).Name)
            {
                case "btnLogin":
                    // Activate the login screen (SecurityView) in the SecurityModule
                    RaiseViewEvent(MvpVm.SecurityModule, MvpVm.SecurityView, ProcessType.ActivateView);
                    break;

                case "btnMainView":
                    // Activate the login screen (SecurityView) in the SecurityModule
                    RaiseModuleEvent(MvpVm.MainModule, MvpVm.MainView, ModuleEventType.Login);
                    break;
            }
        }
        
        public override void MessageEventHandler(MessageEventArgs e)
        {
            ViewModel.Message = e.Message;
        }
    }
}
