﻿using System.Windows.Controls;
using Microsoft.Practices.Unity;
using MsdnDemo.Base;
using MsdnDemo.Infrastructure.Portable.Constants;
using MsdnDemo.Infrastructure.Portable.Entities;
using MsdnDemo.Infrastructure.Portable.Events;
using MsdnDemo.Infrastructure.Portable.Interfaces;
using MsdnDemo.Infrastructure.Portable.Types;
using MsdnDemo.LayerBusinessLogic.Interfaces;
using MsdnDemo.MvpVmViewModels;
using MsdnDemo.MvpVmViews;

namespace MsdnDemo.MvpVmPresenters
{
    public class MainPresenter : PresentationPresenterBase<MainView,MainViewModel>
    {
        [Dependency]
        public ISecurityViewModel SecurityViewModel { get; set; }

        [Dependency]
        public IUserBll UserBll { get; set; }

        protected override void Initialize()
        {
            base.Initialize(); // Logs initialize

            // Add the view model to the view model holder
            View.ViewModelHolder.Items.Add(ViewModel);

        }

        public override void ViewActivated(ViewEventArgs e)
        {
            base.ViewActivated(e); // Log it

            // Assign role flags as applicable
            ViewModel.IsAdmin = SecurityViewModel.IsInRole("Admin");
            ViewModel.IsGuest = SecurityViewModel.IsInRole("Guest");

            if (ViewModel.IsAdmin)
            {
                // Get the complete user list and update view model
                ViewModel.UserList = UserBll.GetUserList();
                ViewModel.SelectedUser = ViewModel.UserList[0];
            }
            else
            {
                // Get the user record for this user and update view model
                var userArgs = new DalEventArgs { PrimaryKey = SecurityViewModel.Id };
                var status = UserBll.Read(userArgs);
                if (status == StatusCode.Success)
                    ViewModel.SelectedUser = userArgs.GetResults<UserEntity>();
            }
        }

        protected override void ExecuteButtonCommandHandler(object sender, DelegateCommandEventArgs e)
        {
            base.ExecuteButtonCommandHandler(sender, e); // Log we are here

            var buttonName = ((Button)e.Sender).Name;

            switch(buttonName)
            {
                case "btnLogin":
                    // Activate the login screen (SecurityView) in the SecurityModule
                    RaiseViewEvent(MvpVm.SecurityModule, MvpVm.SecurityView, ProcessType.ActivateView);
                    break;

                case "btnGuestView":
                    // Activate the login screen (SecurityView) in the SecurityModule
                    RaiseModuleEvent(MvpVm.GuestModule, MvpVm.GuestView, ModuleEventType.Login);
                    break;
            }
        }
    }
}
