﻿using System.Windows.Controls;
using Microsoft.Practices.Unity;
using MsdnDemo.Base;
using MsdnDemo.Infrastructure.Portable.Constants;
using MsdnDemo.Infrastructure.Portable.Events;
using MsdnDemo.LayerBusinessLogic.Interfaces;
using MsdnDemo.MvpVmViewModels;
using MsdnDemo.MvpVmViews;

namespace MsdnDemo.MvpVmPresenters
{
    public class SecurityPresenter : PresentationPresenterBase<SecurityView, SecurityViewModel> 
    {
        [Dependency]
        public IUserBll UserBll { get; set; }

        protected override void Initialize()
        {
            base.Initialize();

            // Add the initialized view model to the ItemsControl
            View.ViewModelHolder.Items.Add(ViewModel);
        }

        /// <summary>
        /// Executes the button command handler.  Works with the ButtonCommand
        /// in the superclass which is bound to in the ButtonStyle 
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="MsdnDemo.Infrastructure.Portable.Events.DelegateCommandEventArgs"/> instance containing the event data.</param>
        protected override void ExecuteButtonCommandHandler(object sender, DelegateCommandEventArgs e)
        {
            ViewModel.Message = null; // reset message
            
            base.ExecuteButtonCommandHandler(sender, e); // Log that we are here
            
            var buttonName = ((Button) e.Sender).Name;

            // Save typing for demo
            if (ViewModel.UserInfo.Login!=null && !ViewModel.UserInfo.Login.Contains("@mydomain.net"))
                ViewModel.UserInfo.Login += "@mydomain.net";
            
            // Authenticate current login using provided password
            ViewModel.IsAuthenticated = UserBll.AuthenticateUser(ViewModel.Password);

            if (!ViewModel.IsAuthenticated)
            {
                var login = ViewModel.UserInfo.Login;
                if (string.IsNullOrEmpty(login) || string.IsNullOrEmpty(ViewModel.Password))
                    RaiseMessageEvent("Login/Password cannot be blank!");
                else
                    RaiseMessageEvent(string.Format("{0} is not authenticated!\r\nLogin and/or Password invalid", ViewModel.UserInfo.Login));
                return;
            }

            switch (buttonName)
            {
                case "btnLogin":
                    // If the user is a Guest then send them to the GuestModule/View
                    if (ViewModel.IsGuest)
                        RaiseModuleEvent(MvpVm.GuestModule, MvpVm.GuestView, ModuleEventType.Login);
                    else
                        // Everyone else goes to the MainModule/View
                        RaiseModuleEvent(MvpVm.MainModule, MvpVm.MainView, ModuleEventType.Login);
                    break;
            }
        }

        public override void MessageEventHandler(MessageEventArgs e)
        {
            // We only want to capture messages received from this
            // presenter processing
            if (e.Sender is SecurityPresenter)
                ViewModel.Message = e.Message;
        }

    }
}
