﻿using System.Collections.Generic;
using MsdnDemo.Base;
using MsdnDemo.Infrastructure.Portable.Entities;

namespace MsdnDemo.MvpVmViewModels
{
    public class MainViewModel : PresentationViewModelBase
    {
        private string _message;
        private List<UserEntity> _userList;

        public string Message
        {
            get { return _message; }
            set
            {
                _message = value;
                OnPropertyChanged("Message");
            }
        }


        public List<UserEntity> UserList
        {
            get { return _userList; }
            set
            {
                _userList = value;
                
                if (value != null)
                    SelectedUser = value[0];

                OnPropertyChanged("UserList");
            }
        }


        #region lazy instantiation of _selected user if doesn't exist
        // We're going to cheat and use a backing field as a property
        // so that we can perform lazy instantiation if the _selectedUser
        // is null (preventing us from having to do it in each property)
        private UserEntity __selectedUser;
        private UserEntity _selectedUser
        {
            get
            {
                if (__selectedUser == null)
                    __selectedUser = new UserEntity();
                return __selectedUser;
            }
            set { __selectedUser = value; }
        }
        #endregion 

        // Our UserEntity does not implement INotifyPropertyChanged
        // So we'll wrap it at the ViewModel level and make the
        // applicable notification 

        public UserEntity SelectedUser
        {
            get { return _selectedUser; }
            set
            {
                _selectedUser = value;

                OnPropertyChanged("SelectedUser");
                OnPropertyChanged("FirstName");
                OnPropertyChanged("LastName");
                OnPropertyChanged("Password");
                OnPropertyChanged("PrimaryEmail");
            }
        }

        public string FirstName
        {
            get { return _selectedUser.FirstName; }
            set
            {
                _selectedUser.FirstName = value;
                OnPropertyChanged("FirstName");
            }
        }

        public string LastName
        {
            get { return _selectedUser.LastName; }
            set
            {
                _selectedUser.LastName = value;
                OnPropertyChanged("LastName");
            }
        }

        public string Password
        {
            get { return _selectedUser.Password; }
            set { _selectedUser.Password = value; }
        }

        public string PrimaryEmail
        {
            get { return _selectedUser.PrimaryEmail; }
            set
            {
                _selectedUser.PrimaryEmail = value;
                OnPropertyChanged("PrimaryEmail");
            }
        }
    }
}
