﻿using System;
using MsdnDemo.Infrastructure.Portable.Logger;

namespace MsdnDemo.Infrastructure.Portable.Base
{
    public class ModuleBase
    {
        public virtual ILogger Logger { get; set; }

        /// <summary>
        /// Called by Prism catalog manager.  Provides hook 
        /// to register types/views and initialize the view model
        /// </summary>
        public virtual void Initialize()
        {
            try
            {
                // Provide hooks for registrations
                RegisterTypes();
                RegisterViews();

                InitializeModule();
            }
            catch (Exception ex)
            {
                Logger.Log("ERROR in [{0}] {1}{2}", 
                    GetType().Name, ex.Message, ex.StackTrace);
            }
        }

        protected virtual void RegisterTypes()
        {
            Logger.Log("{0}.RegisterTypes", GetType());
        }

        protected virtual void RegisterViews()
        {
            Logger.Log("{0}.RegisterViews", GetType());
        }

        protected virtual void InitializeModule()
        {
            Logger.Log("{0}.InitializeModules()", GetType());
        }
    }
}
