﻿using System;

namespace MsdnDemo.Infrastructure.Portable.Events
{
    /// <summary>
    /// Data Access Layer Event Args
    /// </summary>
    public class DalEventArgs : EventArgs
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="DalEventArgs"/> class.
        /// </summary>
        public DalEventArgs()
        {
            PrimaryKey = -1;
            PrimaryKeyField = "id";
            IsEventRaised = true;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="DalEventArgs"/> class.
        /// </summary>
        /// <param name="type">The type.</param>
        public DalEventArgs(Enum type) : this()
        {
            Type = type;
        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is event raised.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is event raised; otherwise, <c>false</c>.
        /// </value>
        public bool IsEventRaised { get; set; }
      

        private object _data;
        /// <summary>
        /// Gets or sets the Data.
        /// </summary>
        /// <value>The start date.</value>
        public object Data
        {
            get { return _data; }
            set
            {
                PriorData = _data;
                _data = value;
            }
        }

        /// <summary>
        /// Gets or sets the results.
        /// </summary>
        /// <value>The results.</value>
        public object Results { get; set; }
      
        /// <summary>
        /// Gets or sets the prior data.
        /// </summary>
        /// <value>The prior data.</value>
        public object PriorData { get; set;}

        /// <summary>
        /// Gets or sets the primary key.
        /// </summary>
        /// <value>The primary key.</value>
        public int PrimaryKey { get; set; }

        /// <summary>
        /// Gets or sets the unique key.
        /// </summary>
        /// <value>The unique key.</value>
        public Guid UniqueKey { get; set; }

        /// <summary>
        /// Gets or sets the primary key field.
        /// </summary>
        /// <value>The primary key field.</value>
        public string PrimaryKeyField { get; set; }

        /// <summary>
        /// Gets or sets the exception.
        /// </summary>
        /// <value>The exception.</value>
        public Exception Exception { get; set; }

        /// <summary>
        /// Gets or sets the event args.
        /// </summary>
        /// <value>The event args.</value>
        public EventArgs EventArgs { get; set; }

        /// <summary>
        /// Gets or sets the type.
        /// </summary>
        /// <value>The type.</value>
        public Enum Type { get; set; }

        /// <summary>
        /// Gets or sets the where clause.
        /// </summary>
        /// <value>The where clause.</value>
        public string WhereClause { get; set; }

        /// <summary>
        /// Gets the data.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <returns></returns>
        public T GetData<T>()
        {
            if (Data is T)
                return (T)Data;

            return default(T);

        }

        /// <summary>
        /// Gets the results.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <returns></returns>
        public T GetResults<T>()
        {
            if (Results == null && Data is T)
                return (T)Data;

            if (Results is T)
                return (T)Results;

            return default(T);

        }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is process.
        /// Useful to prevent recursive processing
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is process; otherwise, <c>false</c>.
        /// </value>
        public bool IsProcessing { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is table created.
        /// Necessary because the data access layer will have an opportunity to
        /// create a table prior to the business logic layer - we don't want them
        /// both creating it
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is table created; otherwise, <c>false</c>.
        /// </value>
        public bool IsTableCreated { get; set; }
    }
}
