﻿using System;
using MsdnDemo.Infrastructure.Portable.Types;

namespace MsdnDemo.Infrastructure.Portable.Events
{
    /// <summary>
    /// Data event arguments
    /// </summary>
    public class DataEventArgs : EventArgs
    {
        /// <summary>
        /// Gets or sets the sender id.
        /// </summary>
        /// <value>The sender id.</value>
        public Guid SenderId { get; set; }

        /// <summary>
        /// Gets or sets the sender.
        /// </summary>
        /// <value>The sender.</value>
        public object Sender { get; set; }

        /// <summary>
        /// Gets or sets the type of the process.
        /// </summary>
        /// <value>The type of the process.</value>
        public ProcessType ProcessType { get; set; }

        /// <summary>
        /// Gets or sets the event args.
        /// </summary>
        /// <value>The event args.</value>
        public EventArgs EventArgs { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is sucessful.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is sucessful; otherwise, <c>false</c>.
        /// </value>
        public bool IsSuccessful { get; set; }

        /// <summary>
        /// Gets or sets the message.
        /// </summary>
        /// <value>The message.</value>
        public string Message { get; set; }

        /// <summary>
        /// Gets or sets the friendly message.
        /// </summary>
        /// <value>The friendly message.</value>
        public string FriendlyMessage { get; set; }

        private Exception _exception;
        /// <summary>
        /// Gets or sets the exception.
        /// </summary>
        /// <value>The exception.</value>
        public Exception Exception
        {
            get { return _exception;  }
            set { 
                _exception = value;
                IsSuccessful = false;
            }
        }

        /// <summary>
        /// Gets or sets the call back.
        /// </summary>
        /// <value>The call back.</value>
        public Action<DataEventArgs> CallBack { get; set; }

        /// <summary>
        /// Gets or sets the data.
        /// </summary>
        /// <value>The data.</value>
        public object Data { get; set; }

        /// <summary>
        /// Initializes a new instance of the <see cref="DataEventArgs"/> class.
        /// </summary>
        public DataEventArgs()
        {
            IsSuccessful = true;
        }

        /// <summary>
        /// Initializes a new instance of the <see cref="DataEventArgs"/> class.
        /// </summary>
        /// <param name="data">The data.</param>
        public DataEventArgs(object data) : this()
        {
            Data = data;
        }

        /// <summary>
        /// Gets the data.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <returns></returns>
        public T GetData<T>()
        {
            if (Data is T)
                return (T)Data;

            return default(T);
        }

        /// <summary>
        /// Sets the exception.
        /// </summary>
        /// <param name="ex">The ex.</param>
        public void SetException(Exception ex)
        {
            Exception = ex;
            IsSuccessful = false;
            Message = ex.Message;
        }


        /// <summary>
        /// Gets or sets a value indicating whether this instance is handled by call back.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is handled by call back; otherwise, <c>false</c>.
        /// </value>
        public bool IsHandledByCallBack { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is event raised.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is event raised; otherwise, <c>false</c>.
        /// </value>
        public bool IsEventRaised { get; set; }

        /// <summary>
        /// Gets or sets a value indicating whether this instance is call back status.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if this instance is call back status; otherwise, <c>false</c>.
        /// </value>
        public bool IsCallBackStatus { get; set; }
    }
}
