﻿using System;
using MsdnDemo.Infrastructure.Portable.Types;

namespace MsdnDemo.Infrastructure.Portable.Events
{
    /// <summary>
    /// View Event arguments
    /// </summary>
    public class ViewEventArgs : EventArgs
    {
        /// <summary>
        /// Gets or sets the type of the process.
        /// </summary>
        /// <value>The type of the process.</value>
        public ProcessType ProcessType { get; set; }

        /// <summary>
        /// Gets or sets the view.
        /// </summary>
        /// <value>The view.</value>
        public object View { get; set; }

        /// <summary>
        /// Gets or sets the name of the module.
        /// </summary>
        /// <value>The name of the module.</value>
        public string ModuleName { get; set; }

        /// <summary>
        /// Gets or sets the view name to activate.
        /// </summary>
        /// <value>The view name to activate.</value>
        public string ViewNameToActivate { get; set; }

        /// <summary>
        /// Gets or sets the view to activate.
        /// </summary>
        /// <value>The view to activate.</value>
        public Type ViewTypeToActivate { get; set; }

        /// <summary>
        /// Gets the view.
        /// </summary>
        /// <typeparam name="T"></typeparam>
        /// <returns></returns>
        public T GetView<T>()
        {
            if (View is T)
                return (T)View;
            return default(T);
        }

        /// <summary>
        /// Returns a <see cref="System.String"/> that represents this instance.
        /// </summary>
        /// <returns>
        /// A <see cref="System.String"/> that represents this instance.
        /// </returns>
        public override string ToString()
        {
            return string.Format(
                "ProcessType: {0}  View:{1}   ViewTypeToActivate:{2}",
                ProcessType,
                View,
                ViewTypeToActivate);
        }

    }
}
