﻿using System;
using System.Collections.Generic;
using MsdnDemo.Infrastructure.Portable.Events;

namespace MsdnDemo.Infrastructure.Portable.Interfaces
{
    /// <summary>
    /// Data Access Layer interface
    /// </summary>
    public interface IDal<TEntity>
    {
        /// <summary>
        /// Occurs when [data arrived read event].
        /// </summary>
        event EventHandler<DataEventArgs> DataArrivedReadEvent;

        /// <summary>
        /// Gets or sets the connection string.
        /// </summary>
        /// <value>The connection string.</value>
        string ConnectionString { get; set; }

        /// <summary>
        /// Creates the table.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        /// <returns></returns>
        int CreateTable(object sender, EventArgs e);

        /// <summary>
        /// Drops the table.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        /// <returns></returns>
        int DropTable(object sender, EventArgs e);

        /// <summary>
        /// Creates the specified record.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        /// <returns></returns>
        int Create(object sender, EventArgs e);

        /// <summary>
        /// Reads the specified record.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        /// <returns></returns>
        TEntity Read(object sender, EventArgs e);

        /// <summary>
        /// Reads the list.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        /// <returns></returns>
        IEnumerable<TEntity> ReadList(object sender, EventArgs e);

        /// <summary>
        /// Updates the specified record.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        /// <returns></returns>
        int Update(object sender, EventArgs e);

        /// <summary>
        /// Deletes the specified record.
        /// </summary>
        /// <param name="sender">The sender.</param>
        /// <param name="e">The <see cref="EventArgs"/> instance containing the event data.</param>
        /// <returns></returns>
        int Delete(object sender, EventArgs e);

        /// <summary>
        /// Sets the connection string.
        /// </summary>
        /// <param name="connectionString">The connection string.</param>
        void SetConnectionString(string connectionString);

        /// <summary>
        /// Table does not exist during read list.
        /// </summary>
        /// <param name="e">The <see cref="DalEventArgs"/> instance containing the event data.</param>
        void TableDoesNotExistHandler(DalEventArgs e);

    }
}
