﻿using System.Linq;
using Microsoft.Practices.Unity;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using MsdnDemo.Infrastructure.Portable.Events;
using MsdnDemo.Infrastructure.Portable.Types;
using MsdnDemo.Mvc3.Tests.Base;
using MsdnDemo.Mvc3.Tests.Mocks;
using MsdnDemo.Infrastructure.Portable.Constants;
using MsdnDemo.Events;
using System;

namespace MsdnDemo.Mvc3.Tests.Layers
{
    [TestClass]
    public class DataLayerFixture : FixtureBase
    {
        [TestInitialize]
        public void InitializeTest()
        {
            Initialize();
        }

        /// <summary>
        /// Determines whether this instance [can create read update delete list dal].
        /// </summary>
        [TestMethod, Owner("Layers")]
        public void CanCreateReadUpdateDeleteListDal()
        {
            var dal = Container.Resolve<MockDal>();

            try
            {
                dal.CreateTable(this, null);
            }
            catch(Exception ex)
            {
                // The BllBase will trap for errors where
                // the table already exists and handle
                // accordingly.  This isn't an error for unit testing
                // since more errors (below) will let us know
                if (!ex.Message.ToLower().Contains("already exists"))
                    throw;
            }

            var record = new MockEntity {Login = "Bill", Password = "Password"};

            var primaryKey = dal.Create(record, new DalEventArgs
                                   {
                                       Type = ProcessType.DataCreate,
                                       Data = record
                                   });

            record.Id = primaryKey;

            var data = dal.Read(this, new DalEventArgs
                        {
                            Type = ProcessType.DataRead,
                            PrimaryKey = primaryKey
                        });

            Assert.AreEqual(primaryKey, data.Id);
            Assert.AreEqual("Bill", data.Login);
            Assert.AreEqual("Password", data.Password);

            record.Password = "NewPassword";

            var status = dal.Update(this, new DalEventArgs
                                {
                                    Type = ProcessType.DataUpdate,
                                    Data = record,
                                    PrimaryKey = record.Id
                                });

            Assert.AreEqual(StatusCode.Success, status);

            data = dal.Read(this, new DalEventArgs
            {
                Type = ProcessType.DataRead,
                PrimaryKey = primaryKey
            });

            Assert.IsNotNull(data);
            Assert.AreEqual(primaryKey, data.Id);
            Assert.AreEqual("NewPassword", data.Password);

            var dataList = dal.ReadList(this, new DalEventArgs { Type = ProcessType.DataList });
            Assert.IsNotNull(dataList);
            Assert.IsTrue(dataList.Count() > 0);
            Assert.IsNotNull(dataList.FirstOrDefault(r => r.Id == primaryKey));


            status = dal.Delete(this, new DalEventArgs
                            {
                                Type=ProcessType.DataDelete,
                                PrimaryKey = primaryKey
                            });
            
            Assert.AreEqual(StatusCode.Success, status);


            data = dal.Read(this, new DalEventArgs
            {
                Type = ProcessType.DataRead,
                PrimaryKey = primaryKey
            });
            Assert.IsNull(data);

            // cleanup
            dal.DropTable(this, null);

        }
    }
}
