﻿#define SqliteTest
using System.Linq;
using System.Collections.Generic;
using Microsoft.Practices.Unity;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using MsdnDemo.Infrastructure.Portable.Constants;
using MsdnDemo.Infrastructure.Portable.Entities;
using MsdnDemo.Infrastructure.Portable.Events;
using MsdnDemo.Infrastructure.Portable.Interfaces;
using MsdnDemo.LayerBusinessLogic;
using MsdnDemo.LayerBusinessLogic.Interfaces;
using MsdnDemo.LayerDataAccess;
using MsdnDemo.Mvc3.Tests.Base;
using MsdnDemo.Mvc3.Tests.Mocks;

namespace MsdnDemo.Mvc3.Tests.Layers
{
    [TestClass]
    public class RolesFixture : FixtureBase
    {
        private IBll _testBll;

        [TestInitialize]
        public void InitializeTest()
        {
            // Registers default values (normally supplied by Prism)
            Initialize();

            Container
#if SqliteTest
                // Roles
                .RegisterType<IRolesBll, RoleBll>()
                .RegisterType<IDal<RoleEntity>, RolesDal>()
                // UserInfo
                .RegisterType<IUserBll, UserBll>()
                .RegisterType<IDal<UserEntity>, UserDal>()
                // User Role
                .RegisterType<IUserRoleBll, UserRoleBll>()
                .RegisterType<IDal<UserRoleEntity>, UserRoleDal>()
                // Mock
                .RegisterType<IMockBll, MockBll>()
                .RegisterType<IDal<MockEntity>, MockDal>()
                ;
#else
                // TODO: Sql server registrations go here....
#endif

            _testBll = Container.Resolve<IRolesBll>();
            _testBll.Initialize();
        }

        [TestMethod]
        public void EmptyRolesTableCreatesDefaults()
        {
            var resultArgs = new DalEventArgs();

            var status = _testBll.List(resultArgs);
            Assert.AreEqual(StatusCode.Success,status);

            var list = new List<RoleEntity>(
                resultArgs.GetResults<IEnumerable<RoleEntity>>());

            Assert.IsTrue(list.Count > 0, "Default roles should have been created");
            Assert.IsNotNull(list.FirstOrDefault(r => r.Role == "Admin"));
            Assert.IsNotNull(list.FirstOrDefault(r => r.Role == "User"));
            Assert.IsNotNull(list.FirstOrDefault(r => r.Role == "Guest"));

            // Cleanup
            _testBll.DropTable();
        }

    }
}
